# `narwhals.LazyFrame`

::: narwhals.dataframe.LazyFrame
    handler: python
    options:
      members:
        - collect
        - columns
        - drop
        - filter
        - group_by
        - head
        - join
        - lazy
        - rename
        - schema
        - select
        - sort
        - unique
        - with_columns
      show_root_heading: false
      show_source: false
      show_bases: false
